@@ -1,6 +1,8 @@
 from ._m1cnn import M1CNNPreprocessing
 from ._distiller import DistillerPreprocessing
 from ._maldist import MalDistPreprocessing
+# wrappers
+from ._wrappers import OneHotEncoderEIMTC
 # general purpose 
 from sklearn.preprocessing import (
     add_dummy_feature, binarize, Binarizer, FunctionTransformer, KBinsDiscretizer, 
@@ -13,6 +15,8 @@ __all__ = [
     'M1CNNPreprocessing',
     'DistillerPreprocessing',
     'MalDistPreprocessing'
+] + [ # wrappers
+    'OneHotEncoderEIMTC'
 ] + [ # general purpose
     'add_dummy_feature',
     'binarize, Binarizer',
